==============
Cassandra Step
==============


.. image:: https://img.shields.io/pypi/v/cassandra_step.svg
        :target: https://pypi.python.org/pypi/cassandra_step

.. image:: https://img.shields.io/travis/molssi-seamm/cassandra_step.svg
        :target: https://travis-ci.org/molssi-seamm/cassandra_step

.. image:: https://readthedocs.org/projects/cassandra-step/badge/?version=latest
        :target: https://cassandra-step.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/molssi-seamm/cassandra_step/shield.svg
     :target: https://pyup.io/repos/github/molssi-seamm/cassandra_step/
     :alt: Updates

.. image:: https://codecov.io/gh/molssi-seamm/cassandra_step/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/molssi-seamm/cassandra_step


Cassandra is a Monte Carlo molecular simulation package.


* Free software: BSD license
* Documentation: https://cassandra-step.readthedocs.io.


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

